@@ -60,7 +60,7 @@ param_rmst = function(Y, A, X, mu_hat, Subgrps, alpha_ovrl, alpha_s, combine="ad
 
   indata = data.frame(Y=Y, A=A, X)
   ### Loop through subgroups ##
-  looper = function(s){
+  looper = function(s, alpha){
     time = indata$Y[Subgrps %in% s,1]
     status = indata$Y[Subgrps %in% s,2]
     arm = indata$A[Subgrps %in% s]
@@ -73,29 +73,29 @@ param_rmst = function(Y, A, X, mu_hat, Subgrps, alpha_ovrl, alpha_s, combine="ad
     if (is.list(obj)){
       est = obj$unadjusted.result[1,1]
       SE = sqrt( obj$RMST.arm1$rmst.var + obj$RMST.arm0$rmst.var )
-      LCL =  est - qnorm(1-alpha_s/2)*SE
-      UCL =  est + qnorm(1-alpha_s/2)*SE
+      LCL =  est - qnorm(1-alpha/2)*SE
+      UCL =  est + qnorm(1-alpha/2)*SE
       pval = obj$unadjusted.result[1,4]
+      summ = data.frame( Subgrps = ifelse(n.s==dim(indata)[1], 0, s),
+                         N = n.s, est, SE, LCL, UCL, pval)
     }
-    return( c(est, SE, LCL, UCL, pval) )
+    return( summ )
   }
+  # Across Subgroups #
   S_levels = as.numeric( names(table(Subgrps)) )
-  S_N = as.numeric( table(Subgrps) )
-  param.dat = lapply(S_levels, looper)
+  param.dat = lapply(S_levels, looper, 
+                     alpha = ifelse( length(unique(Subgrps))==1, alpha_ovrl, alpha_s))
   param.dat = do.call(rbind, param.dat)
-  param.dat = data.frame( S = S_levels, N=S_N, param.dat)
-  colnames(param.dat) = c("Subgrps", "N", "est", "SE", "LCL", "UCL", "pval")
+  param.dat = data.frame( param.dat )
   # Combine results and estimate effect in overall population #
   if ( sum(is.na(param.dat$est))>0 | length(unique(Subgrps))==1  ){
-    param.dat0 = looper(s=S_levels)
-    param.dat0 = data.frame( Subgrps=0, N=dim(X)[2],
-                             param.dat0 )
+    param.dat = param.dat
   }
-  if ( sum(is.na(param.dat$est))==0){
+  if ( sum(is.na(param.dat$est))==0 & length(unique(Subgrps))>1){
     param.dat0 = param_combine(param.dat = param.dat, alpha_ovrl=alpha_ovrl,
                                combine=combine)
+    param.dat = rbind(param.dat0, param.dat)
   }
-  param.dat = rbind(param.dat0, param.dat)
   param.dat$estimand = "RMST(1-0)"
   param.dat = param.dat[,c("Subgrps", "N", "estimand", "est", "SE", "LCL", "UCL", "pval")]
   return( param.dat )
